<?php
if ( ! defined( 'ABSPATH' ) ) exit;

global $post;
$is_kitchen = ROS_Shortcodes::is_kitchen();
wp();
ob_start(); wp_head(); $wp_head = ob_get_clean();
$body_bg = $is_kitchen ? '#0d0d0d' : '#F8F6F2';
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
  <meta charset="<?php bloginfo('charset'); ?>">
  <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no">
  <meta name="theme-color" content="#1A1A1A">
  <title><?php echo esc_html(get_the_title($post)); ?></title>
  <?php echo $wp_head; ?>
  <style>
    *, *::before, *::after { box-sizing: border-box; }
    html { margin:0; padding:0; background:<?php echo $body_bg; ?>; }
    body {
      margin: 0 !important;
      padding: 0 !important;
      background: <?php echo $body_bg; ?> !important;
      /* Normal scroll — no overflow:hidden, no position:fixed tricks */
      min-height: 100vh;
      -webkit-text-size-adjust: 100%;
    }
    /* Kill every theme element that might load */
    #wpadminbar, header, footer, nav, aside,
    .site-header, .site-footer, .navbar,
    #header, #footer, #sidebar { display:none !important; }
  </style>
</head>
<body>
<?php echo do_shortcode($post->post_content); ?>
<?php wp_footer(); ?>
</body>
</html>
