/*!
 * elFinder-Material-Theme (Light) v3.0.1 (https://github.com/RobiNN1/elFinder-Material-Theme)
 * Copyright 2016-2025 Róbert Kelčák
 * Licensed under MIT (https://github.com/RobiNN1/elFinder-Material-Theme/blob/master/LICENSE)
 */
.elfinder {
  color-scheme: light;
  color: #222;
  font-family: Roboto, 'Helvetica Neue', Arial, 'Noto Sans', 'Liberation Sans', -apple-system, 'Segoe UI', sans-serif;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.elfinder * {
  outline: 0 !important;
}
.elfinder .ui-button,
.elfinder .ui-icon,
.elfinder .ui-widget-overlay,
.elfinder .ui-widget-shadow,
.elfinder .ui-widget-header,
.elfinder .ui-widget-header .ui-icon,
.elfinder .ui-widget-content,
.elfinder .ui-widget-content .ui-icon,
.elfinder .ui-state-default,
.elfinder .ui-state-default .ui-icon,
.elfinder .ui-widget-header .ui-state-default,
.elfinder .ui-widget-content .ui-state-default,
.elfinder .ui-state-hover,
.elfinder .ui-state-hover .ui-icon,
.elfinder .ui-widget-header .ui-state-hover,
.elfinder .ui-widget-content .ui-state-hover,
.elfinder .ui-state-active,
.elfinder .ui-state-active .ui-icon,
.elfinder .ui-widget-header .ui-state-active,
.elfinder .ui-widget-content .ui-state-active,
.elfinder .ui-state-focus,
.elfinder .ui-state-focus .ui-icon,
.elfinder .ui-widget-header .ui-state-focus,
.elfinder .ui-widget-content .ui-state-focus,
.ace_optionsMenuEntry button {
  background-image: none;
}
.elfinder.ui-widget.ui-widget-content {
  font-family: Roboto, 'Helvetica Neue', Arial, 'Noto Sans', 'Liberation Sans', -apple-system, 'Segoe UI', sans-serif;
  box-shadow: 0 1px 8px rgba(0, 0, 0, 0.6);
  border-radius: 0;
  border: 0;
}
.elfinder fieldset {
  border-color: rgba(0, 0, 0, 0.4) !important;
}
/**
 * Loading
 */
@keyframes rotate-animation {
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(360deg);
  }
}
.elfinder-spinner,
.elfinder-info-spinner,
.elfinder-navbar-spinner,
.elfinder-button-icon-spinner {
  font-size: 16px;
  background: none;
}
.elfinder-spinner:before,
.elfinder-info-spinner:before,
.elfinder-navbar-spinner:before,
.elfinder-button-icon-spinner:before {
  display: inline-block;
  animation: rotate-animation 1s linear infinite;
}
/**
 * Progress Bar
 */
@keyframes progress-animation {
  from {
    background-position: 1rem 0;
  }
  to {
    background-position: 0 0;
  }
}
.elfinder-notify-progressbar {
  border-radius: 0;
  border: 0;
  background: rgba(0, 0, 0, 0.6);
}
.elfinder-notify-progress {
  border-radius: 0;
  border: 0;
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-size: 1rem 1rem;
  animation: progress-animation 1s linear infinite;
  background-color: #0275d8;
  height: 1rem;
}
/**
 * Toast Notification
 */
.elfinder .elfinder-toast > div {
  box-shadow: none;
  opacity: unset;
  color: #fff;
}
.elfinder .elfinder-toast > div:before {
  font-size: 24px;
  position: absolute;
  left: 10px;
  line-height: 20px;
}
.elfinder .elfinder-toast > .toast-info {
  background-image: none !important;
  background-color: #0d47a1;
}
.elfinder .elfinder-toast > .toast-info button.ui-button {
  background-color: #1366e8;
}
.elfinder .elfinder-toast > .toast-error {
  background-image: none !important;
  background-color: #b71c1c;
}
.elfinder .elfinder-toast > .toast-error button.ui-button {
  background-color: #e13e3e;
}
.elfinder .elfinder-toast > .toast-success {
  background-image: none !important;
  background-color: #1b5e20;
}
.elfinder .elfinder-toast > .toast-success button.ui-button {
  background-color: #2c9934;
}
.elfinder .elfinder-toast > .toast-warning {
  background-image: none !important;
  background-color: #f57f17;
}
.elfinder .elfinder-toast > .toast-warning button.ui-button {
  background-color: #f8a760;
}
/**
 * Icons
 */
@font-face {
  font-family: material;
  src: url("../font/material.eot?3.0.1");
  src: url("../font/material.eot?3.0.1#iefix") format("embedded-opentype"), url("../font/material.woff2?3.0.1") format("woff2"), url("../font/material.woff?3.0.1") format("woff"), url("../font/material.ttf?3.0.1") format("truetype"), url("../font/material.svg?3.0.1#material") format("svg");
  font-weight: normal;
  font-style: normal;
}
.elfinder .ui-icon,
.elfinder-button-icon,
.elfinder-navbar .ui-resizable-handle,
.elfinder-quicklook-navbar-icon,
.elfinder-navbar-icon,
.elfinder-navbar-arrow,
.elfinder-contextmenu-arrow,
.elfinder-dialog-icon,
.elfinder-cwd-icon {
  font-family: material;
  font-size: 14px;
  text-indent: 0;
}
.elfinder .ui-icon:before,
.elfinder-button-icon:before,
.elfinder-navbar .ui-resizable-handle:before,
.elfinder-quicklook-navbar-icon:before,
.elfinder-navbar-icon:before,
.elfinder-navbar-arrow:before,
.elfinder-contextmenu-arrow:before,
.elfinder-dialog-icon:before,
.elfinder-cwd-icon:before {
  display: inline-block;
}
.elfinder-cwd-icon:before {
  font-family: material;
}
.elfinder-button-icon-home:before {
  content: '\e800';
}
.elfinder-button-icon-back:before {
  content: '\e802';
  rotate: 180deg;
}
.elfinder-button-icon-forward:before {
  content: '\e802';
}
.elfinder-button-icon-up:before {
  content: '\e802';
  rotate: -90deg;
}
.elfinder-button-icon-dir:before {
  content: '\e804';
}
.elfinder-button-icon-opendir:before {
  content: '\e805';
}
.elfinder-button-icon-reload:before {
  content: '\e806';
}
.elfinder-button-icon-open:before {
  content: '\e807';
}
.elfinder-button-icon-mkdir:before {
  content: '\e808';
}
.elfinder-button-icon-mkfile:before {
  content: '\e809';
}
.elfinder-button-icon-rm:before {
  content: '\e80a';
}
.elfinder-button-icon-trash:before {
  content: '\e80b';
}
.elfinder-button-icon-restore:before {
  content: '\e80c';
}
.elfinder-button-icon-copy:before {
  content: '\e80d';
}
.elfinder-button-icon-cut:before {
  content: '\e80e';
}
.elfinder-button-icon-paste:before {
  content: '\e80f';
}
.elfinder-button-icon-getfile:before {
  content: '\e810';
}
.elfinder-button-icon-duplicate:before {
  content: '\e811';
}
.elfinder-button-icon-rename:before {
  content: '\e812';
}
.elfinder-button-icon-edit:before {
  content: '\e813';
}
.elfinder-button-icon-quicklook:before {
  content: '\e814';
}
.elfinder-button-icon-upload:before {
  content: '\e815';
}
.elfinder-button-icon-download:before {
  content: '\e816';
}
.elfinder-button-icon-info:before {
  content: '\e817';
}
.elfinder-button-icon-extract:before {
  content: '\e818';
}
.elfinder-button-icon-archive:before {
  content: '\e819';
}
.elfinder-button-icon-view:before {
  content: '\e81a';
}
.elfinder-button-icon-view-list:before {
  content: '\e81b';
}
.elfinder-button-icon-help:before {
  content: '\e81c';
}
.elfinder-button-icon-resize:before {
  content: '\e81d';
}
.elfinder-button-icon-link:before {
  content: '\e81e';
}
.elfinder-button-icon-search:before {
  content: '\e81f';
}
.elfinder-button-icon-sort:before {
  content: '\e820';
}
.elfinder-button-icon-rotate-r:before {
  content: '\e821';
}
.elfinder-button-icon-rotate-l:before {
  content: '\e821';
  transform: scaleX(-1);
}
.elfinder-button-icon-netmount:before {
  content: '\e823';
}
.elfinder-button-icon-netunmount:before {
  content: '\e824';
}
.elfinder-button-icon-places:before {
  content: '\e825';
}
.elfinder-button-icon-chmod:before {
  content: '\e826';
}
.elfinder-button-icon-accept:before {
  content: '\e827';
}
.elfinder-button-icon-menu:before {
  content: '\e828';
}
.elfinder-button-icon-colwidth:before {
  content: '\e829';
}
.elfinder-button-icon-fullscreen:before {
  content: '\e82a';
}
.elfinder-button-icon-unfullscreen:before {
  content: '\e82b';
}
.elfinder-button-icon-empty:before {
  content: '\e82c';
}
.elfinder-button-icon-undo:before {
  content: '\e82d';
}
.elfinder-button-icon-redo:before {
  content: '\e82d';
  transform: scaleX(-1);
}
.elfinder-button-icon-preference:before {
  content: '\e82f';
}
.elfinder-button-icon-mkdirin:before {
  content: '\e830';
}
.elfinder-button-icon-selectall:before {
  content: '\e831';
}
.elfinder-button-icon-selectnone:before {
  content: '\e832';
}
.elfinder-button-icon-selectinvert:before {
  content: '\e833';
}
.elfinder-button-icon-opennew:before {
  content: '\e85b';
}
.elfinder-button-icon-hide:before {
  content: '\e85d';
}
.elfinder-button-icon-text:before {
  content: '\e859';
}
.elfinder-spinner,
.elfinder-info-spinner,
.elfinder-navbar-spinner,
.elfinder-button-icon-spinner {
  background-image: none;
  font-family: material;
}
.elfinder-spinner:before,
.elfinder-info-spinner:before,
.elfinder-navbar-spinner:before,
.elfinder-button-icon-spinner:before {
  content: '\e846';
}
.elfinder-navbar-icon:before {
  content: '\e804';
}
.elfinder-droppable-active .elfinder-navbar-icon:before,
.elfinder .ui-state-active .elfinder-navbar-icon:before,
.elfinder .ui-state-hover .elfinder-navbar-icon:before {
  content: '\e805';
}
[class*='elfinder-navbar-root-'] .elfinder-cwd-icon,
.elfinder-cwd [class*='elfinder-navbar-root-'].elfinder-droppable-active .elfinder-cwd-icon,
.elfinder-cwd-view-list [class*='elfinder-navbar-root-'] td .elfinder-cwd-icon {
  background-image: none;
}
[class*='elfinder-navbar-root-'] .elfinder-cwd-icon:before,
.elfinder-cwd [class*='elfinder-navbar-root-'].elfinder-droppable-active .elfinder-cwd-icon:before,
.elfinder-cwd-view-list [class*='elfinder-navbar-root-'] td .elfinder-cwd-icon:before {
  font-family: material;
  font-size: 55px;
  top: -10px;
}
.elfinder-navbar-root-local .elfinder-cwd-icon:before,
.elfinder-tree .elfinder-navbar-root-local .elfinder-navbar-icon:before,
.elfinder-cwd-view-list .elfinder-navbar-root-local td .elfinder-cwd-icon:before {
  content: '\e83d';
}
.elfinder-navbar-root-ftp .elfinder-cwd-icon:before,
.elfinder-tree .elfinder-navbar-root-ftp .elfinder-navbar-icon:before,
.elfinder-cwd-view-list .elfinder-navbar-root-ftp td .elfinder-cwd-icon:before {
  content: '\e801';
}
.elfinder-navbar-root-sql .elfinder-cwd-icon:before,
.elfinder-tree .elfinder-navbar-root-sql .elfinder-navbar-icon:before,
.elfinder-cwd-view-list .elfinder-navbar-root-sql td .elfinder-cwd-icon:before {
  content: '\e83e';
}
.elfinder-navbar-root-dropbox .elfinder-cwd-icon:before,
.elfinder-tree .elfinder-navbar-root-dropbox .elfinder-navbar-icon:before,
.elfinder-cwd-view-list .elfinder-navbar-root-dropbox td .elfinder-cwd-icon:before {
  content: '\e83f';
}
.elfinder-navbar-root-googledrive .elfinder-cwd-icon:before,
.elfinder-tree .elfinder-navbar-root-googledrive .elfinder-navbar-icon:before,
.elfinder-cwd-view-list .elfinder-navbar-root-googledrive td .elfinder-cwd-icon:before {
  content: '\e840';
}
.elfinder-navbar-root-onedrive .elfinder-cwd-icon:before,
.elfinder-tree .elfinder-navbar-root-onedrive .elfinder-navbar-icon:before,
.elfinder-cwd-view-list .elfinder-navbar-root-onedrive td .elfinder-cwd-icon:before {
  content: '\e841';
}
.elfinder-navbar-root-box .elfinder-cwd-icon:before,
.elfinder-tree .elfinder-navbar-root-box .elfinder-navbar-icon:before,
.elfinder-cwd-view-list .elfinder-navbar-root-box td .elfinder-cwd-icon:before {
  content: '\e842';
}
.elfinder-navbar-root-trash .elfinder-cwd-icon:before,
.elfinder-tree .elfinder-navbar-root-trash .elfinder-navbar-icon:before,
.elfinder-cwd-view-list .elfinder-navbar-root-trash td .elfinder-cwd-icon:before {
  content: '\e80b';
}
.elfinder-navbar-root-zip .elfinder-cwd-icon:before,
.elfinder-tree .elfinder-navbar-root-zip .elfinder-navbar-icon:before,
.elfinder-cwd-view-list .elfinder-navbar-root-zip td .elfinder-cwd-icon:before {
  content: '\e85c';
}
.elfinder-navbar-root-network .elfinder-cwd-icon:before,
.elfinder-tree .elfinder-navbar-root-network .elfinder-navbar-icon:before,
.elfinder-cwd-view-list .elfinder-navbar-root-network td .elfinder-cwd-icon:before {
  content: '\e823';
}
.elfinder-places .elfinder-navbar-root .elfinder-navbar-icon:before {
  content: '\e825';
}
.elfinder-ltr .elfinder-navbar-collapsed .elfinder-navbar-arrow:before {
  content: '\e857';
}
.elfinder-rtl .elfinder-navbar-collapsed .elfinder-navbar-arrow:before {
  content: '\e858';
}
.elfinder-ltr .elfinder-navbar-expanded .elfinder-navbar-arrow:before,
.elfinder-rtl .elfinder-navbar-expanded .elfinder-navbar-arrow:before {
  content: '\e851';
}
.elfinder-dialog-icon:before {
  content: '\e817';
}
.elfinder-dialog-icon-open:before,
.elfinder-dialog-icon-readdir:before,
.elfinder-dialog-icon-file:before,
.elfinder-dialog-icon-chkdir:before {
  content: '\e805';
}
.elfinder-dialog-icon-reload:before {
  content: '\e846';
}
.elfinder-dialog-icon-mkdir:before {
  content: '\e808';
}
.elfinder-dialog-icon-mkfile:before {
  content: '\e809';
}
.elfinder-dialog-icon-copy:before,
.elfinder-dialog-icon-prepare:before {
  content: '\e80d';
}
.elfinder-dialog-icon-move:before {
  content: '\e837';
}
.elfinder-dialog-icon-chunkmerge:before,
.elfinder-dialog-icon-preupload:before,
.elfinder-dialog-icon-upload:before {
  content: '\e815';
}
.elfinder-dialog-icon-rm:before {
  content: '\e80b';
}
.elfinder-dialog-icon-trash:before {
  content: '\e80a';
}
.elfinder-dialog-icon-download:before {
  content: '\e816';
}
.elfinder-dialog-icon-save:before {
  content: '\e845';
}
.elfinder-dialog-icon-rename:before {
  content: '\e812';
}
.elfinder-dialog-icon-archive:before {
  content: '\e819';
}
.elfinder-dialog-icon-zipdl:before,
.elfinder-dialog-icon-extract:before {
  content: '\e818';
}
.elfinder-dialog-icon-search:before {
  content: '\e81f';
}
.elfinder-dialog-icon-resize:before {
  content: '\e81d';
}
.elfinder-dialog-icon-loadimg:before {
  content: '\e846';
}
.elfinder-dialog-icon-netmount:before {
  content: '\e823';
}
.elfinder-dialog-icon-netunmount:before {
  content: '\e824';
}
.elfinder-dialog-icon-url:before {
  content: '\e81e';
}
.elfinder-dialog-icon-chmod:before {
  content: '\e826';
}
.elfinder-dialog-icon-restore:before {
  content: '\e80c';
}
.elfinder-dialog-icon-undo:before {
  content: '\e82d';
}
.elfinder-dialog-icon-redo:before {
  content: '\e82d';
  transform: scaleX(-1);
}
.elfinder-contextmenu .elfinder-contextmenu-item .elfinder-contextmenu-icon {
  background-image: none;
  font-family: material;
}
.elfinder .elfinder-contextmenu-arrow:before {
  content: '\e857';
}
.elfinder-quicklook-navbar-icon-prev:before {
  content: '\e848';
}
.elfinder-quicklook-navbar-icon-next:before {
  content: '\e848';
  transform: scaleX(-1);
}
.elfinder-quicklook-navbar-icon-fullscreen:before {
  content: '\e84a';
}
.elfinder-quicklook-navbar-icon-fullscreen-off:before {
  content: '\e84b';
}
.elfinder-quicklook-navbar-icon-close:before {
  content: '\e84c';
}
.elfinder .ui-icon {
  background-image: none;
}
.elfinder .ui-icon-search:before {
  content: '\e81f';
}
.elfinder .ui-icon-closethick:before,
.elfinder .ui-icon-close:before {
  content: '\e839';
}
.elfinder .ui-icon-circle-close:before {
  content: '\e84c';
}
.elfinder .ui-icon-gear:before {
  content: '\e82f';
}
.elfinder .ui-icon-gripsmall-diagonal-se:before {
  content: '\e838';
}
.elfinder .ui-icon-locked:before {
  content: '\e834';
}
.elfinder .ui-icon-unlocked:before {
  content: '\e836';
}
.elfinder .ui-icon-arrowrefresh-1-n:before {
  content: '\e821';
}
.elfinder .ui-icon-plusthick:before {
  content: '\e83a';
}
.elfinder .ui-icon-arrowreturnthick-1-s:before {
  content: '\e83b';
}
.elfinder .ui-icon-minusthick:before {
  content: '\e83c';
}
.elfinder .ui-icon-pin-s:before {
  content: '\e84d';
}
.elfinder .ui-icon-check:before {
  content: '\e84e';
}
.elfinder .ui-icon-arrowthick-1-s:before {
  content: '\e850';
  rotate: 180deg;
}
.elfinder .ui-icon-arrowthick-1-n:before {
  content: '\e850';
}
.elfinder .ui-icon-triangle-1-s:before {
  content: '\e851';
}
.elfinder .ui-icon-triangle-1-n:before {
  content: '\e851';
  rotate: 180deg;
}
.elfinder .ui-resizable-handle.ui-resizable-e:before,
.elfinder .ui-icon-grip-dotted-vertical:before {
  content: '\e853';
}
.elfinder-lock,
.elfinder-perms,
.elfinder-symlink {
  background-image: none;
  font-family: material;
  font-size: 15px;
  opacity: 0.9;
}
.elfinder-na .elfinder-perms:before {
  content: '\e824';
}
.elfinder-ro .elfinder-perms:before {
  content: '\e835';
}
.elfinder-wo .elfinder-perms:before {
  content: '\e854';
}
.elfinder-group .elfinder-perms:before {
  content: '\e800';
}
.elfinder-lock:before {
  content: '\e84d';
}
.elfinder-symlink:before {
  content: '\e837';
}
.elfinder .elfinder-toast > div:before {
  font-family: material;
}
.elfinder .elfinder-toast > .toast-info:before {
  content: '\e817';
}
.elfinder .elfinder-toast > .toast-error:before {
  content: '\e855';
}
.elfinder .elfinder-toast > .toast-success:before {
  content: '\e84e';
}
.elfinder .elfinder-toast > .toast-warning:before {
  content: '\e856';
}
.elfinder-drag-helper-icon-status {
  font-family: material;
  font-size: 14px;
  background-image: none;
}
.elfinder-drag-helper-icon-status:before {
  content: '\e824';
}
.elfinder-drag-helper-move .elfinder-drag-helper-icon-status {
  transform: rotate(180deg);
}
.elfinder-drag-helper-move .elfinder-drag-helper-icon-status:before {
  content: '\e854';
}
.elfinder-drag-helper-plus .elfinder-drag-helper-icon-status {
  transform: rotate(90deg);
}
.elfinder-drag-helper-plus .elfinder-drag-helper-icon-status:before {
  content: '\e84c';
}
.elfinder-cwd-icon {
  color: #0d47a1;
}
.elfinder-cwd-icon:not(.elfinder-cwd-bgurl):before {
  content: '\e803';
}
.elfinder-cwd-icon.elfinder-cwd-bgurl:after {
  content: none !important;
}
.elfinder-cwd-icon.elfinder-cwd-icon-directory:before {
  content: '\e804';
}
.elfinder-cwd-icon.elfinder-cwd-icon-group:before {
  content: '\e82e';
}
.elfinder-cwd .elfinder-droppable-active .elfinder-cwd-icon:before {
  content: '\e805';
}
.elfinder-cwd-icon-application {
  color: #478fcc;
}
.elfinder-cwd-icon-application:after {
  content: '\e843' !important;
}
.elfinder-cwd-icon-text,
.elfinder-cwd-icon-plain,
.elfinder-cwd-icon-x-empty {
  color: #42a5f5;
}
.elfinder-cwd-icon-text:after,
.elfinder-cwd-icon-plain:after,
.elfinder-cwd-icon-x-empty:after {
  content: '\e84f' !important;
}
.elfinder-cwd-icon-rtf,
.elfinder-cwd-icon-rtfd {
  color: #81c784;
}
.elfinder-cwd-icon-rtf:after,
.elfinder-cwd-icon-rtfd:after {
  content: '\e87c' !important;
}
.elfinder-cwd-icon-image {
  color: #4caf50;
}
.elfinder-cwd-icon-image:after {
  content: '\e847' !important;
}
.elfinder-cwd-icon-audio {
  color: #ef5350;
}
.elfinder-cwd-icon-audio:after {
  content: '\e85a' !important;
}
.elfinder-cwd-icon-video,
.elfinder-cwd-icon-flash-video,
.elfinder-cwd-icon-dash-xml,
.elfinder-cwd-icon-vnd-apple-mpegurl,
.elfinder-cwd-icon-x-mpegurl {
  color: #f44336;
}
.elfinder-cwd-icon-video:after,
.elfinder-cwd-icon-flash-video:after,
.elfinder-cwd-icon-dash-xml:after,
.elfinder-cwd-icon-vnd-apple-mpegurl:after,
.elfinder-cwd-icon-x-mpegurl:after {
  content: '\e849' !important;
}
.elfinder-cwd-icon-pdf {
  color: #d50a0a;
}
.elfinder-cwd-icon-pdf:after {
  content: '\e852' !important;
}
.elfinder-cwd-icon-vnd-ms-office {
  color: #ea3e23;
}
.elfinder-cwd-icon-vnd-ms-office:after {
  content: '\e85e' !important;
}
.elfinder-cwd-icon-x-msaccess {
  color: #af2031;
}
.elfinder-cwd-icon-x-msaccess:after {
  content: '\e85f' !important;
}
.elfinder-cwd-icon-ms-excel,
.elfinder-cwd-icon-vnd-ms-excel,
.elfinder-cwd-icon-vnd-ms-excel-addin-macroEnabled-12,
.elfinder-cwd-icon-vnd-ms-excel-sheet-binary-macroEnabled-12,
.elfinder-cwd-icon-vnd-ms-excel-sheet-macroEnabled-12,
.elfinder-cwd-icon-vnd-ms-excel-template-macroEnabled-12 {
  color: #107c41;
}
.elfinder-cwd-icon-ms-excel:after,
.elfinder-cwd-icon-vnd-ms-excel:after,
.elfinder-cwd-icon-vnd-ms-excel-addin-macroEnabled-12:after,
.elfinder-cwd-icon-vnd-ms-excel-sheet-binary-macroEnabled-12:after,
.elfinder-cwd-icon-vnd-ms-excel-sheet-macroEnabled-12:after,
.elfinder-cwd-icon-vnd-ms-excel-template-macroEnabled-12:after {
  content: '\e860' !important;
}
.elfinder-cwd-icon-vnd-ms-powerpoint,
.elfinder-cwd-icon-vnd-ms-powerpoint-addin-macroEnabled-12,
.elfinder-cwd-icon-vnd-ms-powerpoint-presentation-macroEnabled-12,
.elfinder-cwd-icon-vnd-ms-powerpoint-slide-macroEnabled-12,
.elfinder-cwd-icon-vnd-ms-powerpoint-slideshow-macroEnabled-12,
.elfinder-cwd-icon-vnd-ms-powerpoint-template-macroEnabled-12 {
  color: #c43e1c;
}
.elfinder-cwd-icon-vnd-ms-powerpoint:after,
.elfinder-cwd-icon-vnd-ms-powerpoint-addin-macroEnabled-12:after,
.elfinder-cwd-icon-vnd-ms-powerpoint-presentation-macroEnabled-12:after,
.elfinder-cwd-icon-vnd-ms-powerpoint-slide-macroEnabled-12:after,
.elfinder-cwd-icon-vnd-ms-powerpoint-slideshow-macroEnabled-12:after,
.elfinder-cwd-icon-vnd-ms-powerpoint-template-macroEnabled-12:after {
  content: '\e861' !important;
}
.elfinder-cwd-icon-msword,
.elfinder-cwd-icon-vnd-ms-word,
.elfinder-cwd-icon-vnd-ms-word-document-macroEnabled-12,
.elfinder-cwd-icon-vnd-ms-word-template-macroEnabled-12 {
  color: #185abd;
}
.elfinder-cwd-icon-msword:after,
.elfinder-cwd-icon-vnd-ms-word:after,
.elfinder-cwd-icon-vnd-ms-word-document-macroEnabled-12:after,
.elfinder-cwd-icon-vnd-ms-word-template-macroEnabled-12:after {
  content: '\e862' !important;
}
.elfinder-cwd-icon-vnd-oasis-opendocument-chart,
.elfinder-cwd-icon-vnd-oasis-opendocument-formula,
.elfinder-cwd-icon-vnd-oasis-opendocument-graphics,
.elfinder-cwd-icon-vnd-oasis-opendocument-graphics-template,
.elfinder-cwd-icon-vnd-oasis-opendocument-image,
.elfinder-cwd-icon-vnd-openofficeorg-extension {
  color: #0e85cd;
}
.elfinder-cwd-icon-vnd-oasis-opendocument-chart:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-formula:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-graphics:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-graphics-template:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-image:after,
.elfinder-cwd-icon-vnd-openofficeorg-extension:after {
  content: '\e863' !important;
}
.elfinder-cwd-icon-vnd-oasis-opendocument-text,
.elfinder-cwd-icon-vnd-oasis-opendocument-text-master,
.elfinder-cwd-icon-vnd-oasis-opendocument-text-template,
.elfinder-cwd-icon-vnd-oasis-opendocument-text-web,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-wordprocessingml-document,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-wordprocessingml-template {
  color: #2196f3;
}
.elfinder-cwd-icon-vnd-oasis-opendocument-text:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-text-master:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-text-template:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-text-web:after,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-wordprocessingml-document:after,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-wordprocessingml-template:after {
  content: '\e864' !important;
}
.elfinder-cwd-icon-vnd-oasis-opendocument-presentation,
.elfinder-cwd-icon-vnd-oasis-opendocument-presentation-template,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-presentationml-presentation,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-presentationml-slide,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-presentationml-slideshow,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-presentationml-template {
  color: #ff6d00;
}
.elfinder-cwd-icon-vnd-oasis-opendocument-presentation:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-presentation-template:after,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-presentationml-presentation:after,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-presentationml-slide:after,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-presentationml-slideshow:after,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-presentationml-template:after {
  content: '\e865' !important;
}
.elfinder-cwd-icon-csv,
.elfinder-cwd-icon-vnd-oasis-opendocument-spreadsheet,
.elfinder-cwd-icon-vnd-oasis-opendocument-spreadsheet-template,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-spreadsheetml-sheet,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-spreadsheetml-template {
  color: #43a047;
}
.elfinder-cwd-icon-csv:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-spreadsheet:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-spreadsheet-template:after,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-spreadsheetml-sheet:after,
.elfinder-cwd-icon-vnd-openxmlformats-officedocument-spreadsheetml-template:after {
  content: '\e866' !important;
}
.elfinder-cwd-icon-sql,
.elfinder-cwd-icon-x-sql,
.elfinder-cwd-icon-vnd-oasis-opendocument-base,
.elfinder-cwd-icon-vnd-oasis-opendocument-database {
  color: #607d8b;
}
.elfinder-cwd-icon-sql:after,
.elfinder-cwd-icon-x-sql:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-base:after,
.elfinder-cwd-icon-vnd-oasis-opendocument-database:after {
  content: '\e877' !important;
}
.elfinder-cwd-icon-vnd-adobe-photoshop {
  color: #001e36;
}
.elfinder-cwd-icon-vnd-adobe-photoshop:after {
  content: '\e868' !important;
}
.elfinder-cwd-icon-x-shockwave-flash {
  color: #d91b22;
}
.elfinder-cwd-icon-x-shockwave-flash:after {
  content: '\e869' !important;
}
.elfinder-cwd-icon-vnd-android-package-archive {
  color: #39cc7a;
}
.elfinder-cwd-icon-vnd-android-package-archive:after {
  content: '\e86a' !important;
}
.elfinder-cwd-icon-x-c,
.elfinder-cwd-icon-x-csrc,
.elfinder-cwd-icon-x-chdr,
.elfinder-cwd-icon-x-c--,
.elfinder-cwd-icon-x-c--src,
.elfinder-cwd-icon-x-c--hdr {
  color: #004482;
}
.elfinder-cwd-icon-x-c:after,
.elfinder-cwd-icon-x-csrc:after,
.elfinder-cwd-icon-x-chdr:after,
.elfinder-cwd-icon-x-c--:after,
.elfinder-cwd-icon-x-c--src:after,
.elfinder-cwd-icon-x-c--hdr:after {
  content: '\e86b' !important;
}
.elfinder-cwd-icon-x-jar,
.elfinder-cwd-icon-x-java,
.elfinder-cwd-icon-x-java-source {
  color: #ed8b00;
}
.elfinder-cwd-icon-x-jar:after,
.elfinder-cwd-icon-x-java:after,
.elfinder-cwd-icon-x-java-source:after {
  content: '\e86c' !important;
}
.elfinder-cwd-icon-css {
  color: #1b73ba;
}
.elfinder-cwd-icon-css:after {
  content: '\e86d' !important;
}
.elfinder-cwd-icon-html {
  color: #e34f26;
}
.elfinder-cwd-icon-html:after {
  content: '\e86e' !important;
}
.elfinder-cwd-icon-javascript,
.elfinder-cwd-icon-x-javascript {
  color: #fbd53b;
}
.elfinder-cwd-icon-javascript:after,
.elfinder-cwd-icon-x-javascript:after {
  content: '\e86f' !important;
}
.elfinder-cwd-icon-json {
  color: #8bc34a;
}
.elfinder-cwd-icon-json:after {
  content: '\e870' !important;
}
.elfinder-cwd-icon-markdown,
.elfinder-cwd-icon-x-markdown {
  color: #ea7130;
}
.elfinder-cwd-icon-markdown:after,
.elfinder-cwd-icon-x-markdown:after {
  content: '\e871' !important;
}
.elfinder-cwd-icon-x-perl {
  color: #3a3c5b;
}
.elfinder-cwd-icon-x-perl:after {
  content: '\e872' !important;
}
.elfinder-cwd-icon-x-php {
  color: #4f5b93;
}
.elfinder-cwd-icon-x-php:after {
  content: '\e873' !important;
}
.elfinder-cwd-icon-x-python {
  color: #306998;
}
.elfinder-cwd-icon-x-python:after {
  content: '\e874' !important;
}
.elfinder-cwd-icon-x-ruby {
  color: #cc342d;
}
.elfinder-cwd-icon-x-ruby:after {
  content: '\e875' !important;
}
.elfinder-cwd-icon-x-sh,
.elfinder-cwd-icon-x-shellscript {
  color: #3d5afe;
}
.elfinder-cwd-icon-x-sh:after,
.elfinder-cwd-icon-x-shellscript:after {
  content: '\e876' !important;
}
.elfinder-cwd-icon-x-sqlite3 {
  color: #3965bd;
}
.elfinder-cwd-icon-x-sqlite3:after {
  content: '\e878' !important;
}
.elfinder-cwd-icon-svg,
.elfinder-cwd-icon-svg-xml {
  color: #ffb13b;
}
.elfinder-cwd-icon-svg:after,
.elfinder-cwd-icon-svg-xml:after {
  content: '\e879' !important;
}
.elfinder-cwd-icon-postscript,
.elfinder-cwd-icon-x-eps {
  color: #00796b;
}
.elfinder-cwd-icon-postscript:after,
.elfinder-cwd-icon-x-eps:after {
  content: '\e87a' !important;
}
.elfinder-cwd-icon-xml {
  color: #005fad;
}
.elfinder-cwd-icon-xml:after {
  content: '\e844' !important;
}
.elfinder-cwd-icon-x-yaml {
  color: #cb171e;
}
.elfinder-cwd-icon-x-yaml:after {
  content: '\e867' !important;
}
.elfinder-cwd-icon-zip,
.elfinder-cwd-icon-x-zip,
.elfinder-cwd-icon-x-xz,
.elfinder-cwd-icon-x-7z-compressed,
.elfinder-cwd-icon-x-gzip,
.elfinder-cwd-icon-x-tar,
.elfinder-cwd-icon-x-bzip,
.elfinder-cwd-icon-x-bzip2,
.elfinder-cwd-icon-x-rar,
.elfinder-cwd-icon-x-rar-compressed {
  color: #fbc02d;
}
.elfinder-cwd-icon-zip:before,
.elfinder-cwd-icon-x-zip:before,
.elfinder-cwd-icon-x-xz:before,
.elfinder-cwd-icon-x-7z-compressed:before,
.elfinder-cwd-icon-x-gzip:before,
.elfinder-cwd-icon-x-tar:before,
.elfinder-cwd-icon-x-bzip:before,
.elfinder-cwd-icon-x-bzip2:before,
.elfinder-cwd-icon-x-rar:before,
.elfinder-cwd-icon-x-rar-compressed:before {
  content: '\e822' !important;
}
.elfinder-cwd-icon-zip:after,
.elfinder-cwd-icon-x-zip:after,
.elfinder-cwd-icon-x-xz:after,
.elfinder-cwd-icon-x-7z-compressed:after,
.elfinder-cwd-icon-x-gzip:after,
.elfinder-cwd-icon-x-tar:after,
.elfinder-cwd-icon-x-bzip:after,
.elfinder-cwd-icon-x-bzip2:after,
.elfinder-cwd-icon-x-rar:after,
.elfinder-cwd-icon-x-rar-compressed:after {
  content: none !important;
}
/**
 * Toolbar
 */
.elfinder-toolbar {
  background: #197dd6;
  border-radius: 0;
  border: 0;
  padding: 3px 20px;
}
.elfinder-toolbar .elfinder-button-icon {
  color: #ffffff;
}
.elfinder-buttonset {
  border-radius: 0;
  border: 0;
  margin: 0 3px;
  background: transparent;
  height: unset;
}
.elfinder-buttonset:nth-child(2) {
  margin-left: 0;
}
.elfinder .elfinder-button:not(.elfinder-button-search) {
  padding: 6px 4px 3px;
  background: transparent;
  overflow: unset;
}
.elfinder .elfinder-button:not(.elfinder-button-search).ui-state-hover .elfinder-button-icon {
  color: #ffffff;
}
.elfinder-button-icon {
  background: none;
  font-size: 20px !important;
  overflow: unset;
}
.elfinder-button-text {
  margin: 0 0 0 1px;
  top: -3px;
  color: #ffffff;
}
.elfinder-toolbar-button-separator {
  border: 0;
  height: unset;
}
.elfinder .elfinder-button-search {
  margin: 3px 0;
  height: unset;
  min-height: unset;
}
.elfinder .elfinder-button-search input[type=text] {
  border-radius: 2px;
  border: 0;
  background: rgba(14, 69, 118, 0.75);
  font-size: 0.71em;
  line-height: unset;
  height: unset;
  padding-left: 20px;
  padding-right: 20px;
}
.elfinder .elfinder-button-search .ui-icon {
  color: rgba(255, 255, 255, 0.75);
  margin: -6px 4px 0;
}
.elfinder-button-search-menu .ui-button {
  margin-left: 2px;
  margin-right: 2px;
}
/**
 * Navbar
 */
.elfinder .elfinder-navbar {
  background: #e6e6e6;
  border-radius: 0;
  border: 0;
}
.elfinder .elfinder-navbar .ui-resizable-handle {
  background-image: none;
  font-size: 12px;
  color: #222;
}
.elfinder .elfinder-navbar .ui-resizable-handle:before {
  position: absolute;
  top: 50% !important;
  transform: translateX(-50%);
}
.elfinder-navbar-dir {
  color: #222;
  cursor: pointer;
  border-radius: 2px;
  border: 0;
  padding: 5px;
}
.elfinder-navbar-dir.ui-state-hover,
.elfinder-navbar-dir.ui-state-active {
  background: #3594e8;
  color: #fff;
  border: 0;
}
.elfinder-navbar-icon {
  background-image: none !important;
  font-size: 16px;
  margin-top: -10px;
}
.elfinder-tree .elfinder-spinner {
  margin: -10px 0 0;
}
.elfinder-navbar-arrow {
  background-image: none !important;
  font-size: 10px;
  padding-top: 2px;
  padding-left: 2px;
}
/**
 * Workzone
 */
.elfinder-workzone {
  background: #fff;
}
.elfinder-cwd-file {
  color: #222;
}
.elfinder-cwd-file .elfinder-cwd-file-wrapper,
.elfinder-cwd-file .elfinder-cwd-filename {
  background: none;
  color: #222;
}
.elfinder-cwd-file .elfinder-cwd-filename textarea {
  height: 15px !important;
}
.elfinder-cwd-file.ui-state-hover,
.elfinder-cwd-file.ui-selected.ui-state-hover {
  background: #4ca0ea;
  color: #fff;
}
.elfinder-cwd-file.ui-state-hover .elfinder-cwd-filename,
.elfinder-cwd-file.ui-selected.ui-state-hover .elfinder-cwd-filename {
  color: #fff;
}
.elfinder-cwd-file.ui-selected {
  background: #3e99e9;
}
.elfinder-cwd-file.ui-selected .elfinder-cwd-filename {
  color: #fff;
}
.elfinder-cwd-file .ui-state-hover,
.elfinder-cwd-file .ui-state-active {
  background: none !important;
  color: #fff;
}
.elfinder-cwd-file .elfinder-lock {
  color: #4caf50;
}
.elfinder-cwd-file .elfinder-perms,
.elfinder-cwd-file .elfinder-symlink {
  color: #555555;
  opacity: unset;
}
.elfinder-cwd table {
  padding: 0;
  border: 0 !important;
}
.elfinder-cwd table thead tr {
  background: none !important;
}
.elfinder-cwd table thead td {
  padding: 5px 14px !important;
  background: #187bd1;
  color: #ffffff;
}
.elfinder-cwd table thead td.ui-state-hover,
.elfinder-cwd table thead td.ui-state-active {
  background: #1360a4 !important;
  color: #ffffff;
}
.elfinder-cwd table .elfinder-lock {
  margin-top: 0;
  opacity: unset;
  font-size: 12px;
}
.elfinder-cwd table .elfinder-perms,
.elfinder-cwd table .elfinder-symlink {
  font-size: 11px;
}
.elfinder-cwd-wrapper-list tr.ui-state-default td span.ui-icon {
  font-size: 8px;
  top: 7px !important;
  right: 7px !important;
}
.elfinder-cwd-view-list thead td .ui-resizable-e {
  font-size: 9px;
  top: 8px;
  right: 0;
}
.elfinder-cwd-icon {
  background-image: none;
  position: relative;
}
.elfinder-cwd-icon:before {
  font-size: 48px;
  line-height: unset;
  width: 48px;
  height: 48px;
  position: relative;
  padding: unset;
  margin-top: -7px;
  display: inline-block !important;
  top: 50% !important;
  transform: translateY(-50%);
}
.elfinder-cwd-icon:after {
  color: #fff;
  font-size: 25px;
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translateY(-50%) translateX(-50%);
}
.elfinder-cwd-icon.elfinder-cwd-bgurl:before {
  content: none;
}
.elfinder-cwd-view-list td .elfinder-cwd-icon {
  background-image: none;
}
.elfinder-cwd-view-list td .elfinder-cwd-icon:before {
  font-size: 16px;
  width: 16px;
  height: 16px;
  left: 50%;
  transform: translateX(-50%) translateY(-50%);
}
.elfinder-cwd-view-list td .elfinder-cwd-icon:after {
  font-size: 8.5px;
  margin-top: 1px;
}
.ui-selectable-helper {
  background-color: rgba(76, 160, 234, 0.38);
  border: 1px solid #4ca0ea;
}
/**
 * Status Bar
 */
.elfinder .elfinder-statusbar {
  border-radius: 0;
  border: 0;
  background: #197dd6;
  color: #ffffff;
  padding: 5px 20px;
  border-bottom: 1px solid #197dd6;
}
/**
 * Forms
 */
.elfinder label.ui-state-hover {
  background: none;
  color: inherit;
}
.elfinder input:not([type="checkbox"]),
.elfinder select,
.elfinder textarea {
  color: #f1f1f1;
  background: #187bd1;
  border-radius: 2px;
  border: 0;
  padding: 5px 4px;
  vertical-align: middle;
}
.elfinder input:not([type="checkbox"]).ui-state-hover,
.elfinder select.ui-state-hover,
.elfinder textarea.ui-state-hover,
.elfinder input:not([type="checkbox"]):focus,
.elfinder select:focus,
.elfinder textarea:focus {
  background: #187bd1;
  color: #f1f1f1;
  border: 0;
}
.elfinder input:not([type="checkbox"])::placeholder,
.elfinder select::placeholder,
.elfinder textarea::placeholder {
  color: #f1f1f1;
}
.elfinder input[type="checkbox"] {
  background: transparent;
  position: relative;
  -webkit-appearance: none;
          appearance: none;
  margin: -2px 3px 0 0;
  vertical-align: middle;
  width: 10px;
  height: 10px;
  border: 2px solid #666;
  border-radius: 2px;
}
.elfinder input[type="checkbox"]:checked {
  background-color: #187bd1;
  border-color: #187bd1;
}
.elfinder input[type="checkbox"]:checked:before {
  content: "";
  position: absolute;
  width: 3px;
  height: 8px;
  border: 2px solid #fff;
  border-top-width: 0;
  border-left-width: 0;
  top: 0;
  left: 3px;
  transform: rotate(45deg);
}
.elfinder button,
.elfinder .ui-button,
.ace_optionsMenuEntry button {
  border-radius: 2px;
  border: 0;
  text-transform: uppercase;
  background: #187bd1;
  color: #fff;
  padding: 5px 7px;
}
.elfinder button:hover,
.elfinder .ui-button:hover,
.elfinder button.ui-state-hover,
.elfinder .ui-button.ui-state-hover,
.ace_optionsMenuEntry button:hover {
  background: #1670bf;
  color: #fff;
  border: 0;
}
.elfinder button.ui-state-active,
.elfinder .ui-button.ui-state-active,
.ace_optionsMenuEntry button[ace_selected_button=true] {
  background: #3594e8;
}
.elfinder .ui-slider-horizontal {
  height: 3px;
  background-color: #187bd1 !important;
}
.elfinder .ui-slider-horizontal .ui-slider-handle {
  background-color: #166dba;
  border-radius: 100%;
  border: 0;
  margin-top: -3px;
}
/**
 * Context Menu
 */
.elfinder .elfinder-contextmenu,
.elfinder .elfinder-contextmenu-sub,
.elfinder-button-menu {
  border-radius: 0;
  border: 0 !important;
  box-shadow: 0 1px 6px rgba(0, 0, 0, 0.3);
  background: #ffffff;
}
.elfinder .elfinder-contextmenu-item,
.elfinder .elfinder-contextmenu-sub-item,
.elfinder-button-menu-item {
  color: #000;
}
.elfinder .elfinder-contextmenu-item.ui-state-hover,
.elfinder .elfinder-contextmenu-sub-item.ui-state-hover,
.elfinder-button-menu-item.ui-state-hover,
.elfinder .elfinder-contextmenu-item.ui-state-active,
.elfinder .elfinder-contextmenu-sub-item.ui-state-active,
.elfinder-button-menu-item.ui-state-active {
  color: #000;
  background: rgba(0, 0, 0, 0.1);
}
.elfinder .elfinder-contextmenu-item .elfinder-button-icon,
.elfinder .elfinder-contextmenu-sub-item .elfinder-button-icon,
.elfinder-button-menu-item .elfinder-button-icon {
  font-size: 14px !important;
  color: #000;
}
.elfinder .elfinder-contextmenu-item .elfinder-button-icon.ui-state-disabled,
.elfinder .elfinder-contextmenu-sub-item .elfinder-button-icon.ui-state-disabled,
.elfinder-button-menu-item .elfinder-button-icon.ui-state-disabled {
  background-image: none;
}
.elfinder .elfinder-contextmenu .ui-icon,
.elfinder .elfinder-contextmenu-sub .ui-icon {
  margin-top: -5px;
}
.elfinder .elfinder-contextmenu-separator,
.elfinder-button-menu-item-separated,
.elfinder-button-menu-item-separated.ui-state-hover {
  border-top: 1px solid rgba(0, 0, 0, 0.4);
}
.elfinder-contextmenu-header {
  border-radius: 0;
  border: 0;
  background: none;
  color: #000;
}
.elfinder .elfinder-contextmenu-extra-icon {
  width: 16px;
}
.elfinder .elfinder-contextmenu-extra-icon a {
  display: block;
}
.elfinder .elfinder-contextmenu-extra-icon a,
.elfinder .elfinder-contextmenu-extra-icon span {
  position: absolute;
  z-index: 10;
  top: 0;
}
.elfinder .elfinder-contextmenu-extra-icon.elfinder-button-icon span:before {
  color: #000;
  line-height: 2;
}
.elfinder .elfinder-contextmenu-arrow {
  background-image: none;
  font-size: 9px !important;
  top: 15px;
}
.elfinder .elfinder-contextmenu-ltr .elfinder-contextmenu-arrow {
  right: 2px;
}
.elfinder-contextsubmenu-item-icon .elfinder-contextmenu-icon {
  width: 16px;
  height: 16px;
}
/**
 * Dialogs
 */
.elfinder-dialog,
.elfinder-quicklook {
  border-radius: 0;
  border: 0 !important;
  box-shadow: 0 1px 6px rgba(0, 0, 0, 0.3);
  background: #fff;
  color: #222;
}
.elfinder-dialog a,
.elfinder-quicklook a {
  color: #151515;
}
.elfinder-dialog .ui-dialog-titlebar,
.elfinder-quicklook .ui-dialog-titlebar {
  border-radius: 0;
  border: 0;
  background: #187bd1;
  color: #fff;
}
.elfinder-dialog .ui-widget-content,
.elfinder-quicklook .ui-widget-content {
  border-radius: 0;
  border: 0;
  background: transparent;
  color: #222;
}
.elfinder-dialog .elfinder-titlebar-button,
.elfinder-quicklook .elfinder-titlebar-button {
  background: none;
}
.elfinder-dialog .elfinder-titlebar-button .ui-icon,
.elfinder-quicklook .elfinder-titlebar-button .ui-icon {
  border: 0;
  color: #222;
  width: unset !important;
  height: unset !important;
}
.elfinder-dialog .elfinder-titlebar-button .ui-icon:hover,
.elfinder-quicklook .elfinder-titlebar-button .ui-icon:hover {
  opacity: 80;
}
.elfinder-dialog .elfinder-cwd-icon:before,
.elfinder-quicklook .elfinder-cwd-icon:before {
  left: 50% !important;
  top: 50%;
  transform: translateY(-50%) translateX(-50%);
}
.elfinder-dialog .elfinder-cwd-icon:after,
.elfinder-quicklook .elfinder-cwd-icon:after {
  left: 50% !important;
}
.elfinder-dialog .ui-dialog-titlebar-close .ui-icon:hover,
.elfinder-titlebar-button .elfinder-icon-close:hover {
  color: #f44336;
}
.elfinder-dialog .elfinder-titlebar-minimize .ui-icon:hover,
.elfinder-titlebar-button .elfinder-icon-minimize:hover {
  color: #ff9800;
}
.elfinder-dialog .elfinder-titlebar-full .ui-icon:hover,
.elfinder-titlebar-button .elfinder-icon-full:hover {
  color: #4caf50;
}
.elfinder-dialog .ui-tabs .ui-tabs-nav {
  background: none;
  border: 0;
  border-bottom: 1px solid #1a83df;
  padding: 0;
  border-radius: 0;
}
.elfinder-dialog .ui-tabs .ui-tabs-tab {
  background: none;
  border-radius: 0;
  border: 0;
}
.elfinder-dialog .ui-tabs .ui-tabs-tab a {
  color: #1a83df;
  margin-bottom: -1px;
}
.elfinder-dialog .ui-tabs .ui-tabs-tab.ui-state-hover a {
  color: #1468b1;
}
.elfinder-dialog .ui-tabs .ui-tabs-tab.ui-state-active a {
  color: #1a86e4;
  border-bottom: 3px solid #1a86e4;
}
.elfinder-dialog .elfinder-dialog-icon {
  background: none;
  font-size: 32px;
  margin-top: -23px;
}
.elfinder-dialog .elfinder-info-tb {
  margin: 1em 0;
}
.elfinder-dialog .elfinder-edit-editor {
  padding: 0;
  background-color: #fff !important;
}
.elfinder-dialog .elfinder-edit-editor textarea {
  border-radius: 0;
  box-shadow: none;
  background: #484848;
  padding: unset;
}
.elfinder-dialog .elfinder-edit-editor .elfinder-button-icon {
  vertical-align: unset;
}
.elfinder-dialog .ui-dialog-buttonpane select,
.elfinder-dialog .ui-dialog-buttonpane .ui-button {
  margin-top: 0 !important;
  margin-bottom: 0;
  padding: 5px 6px;
}
.elfinder-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
  padding-top: 0;
}
.elfinder-dialog .ui-dialog-buttonpane .ui-dialog-buttonset.elfinder-edit-extras {
  margin: 0 0.4em;
}
.elfinder-dialog .ui-dialog-buttonpane .ui-dialog-buttonset.elfinder-edit-extras select {
  padding: 5.2px 5px;
}
.elfinder-dialog .ui-dialog-buttonpane .ui-button-icon {
  transform: translateY(-50%) translateX(-50%);
  margin-top: 0;
  margin-left: 0;
}
.elfinder-dialog .elfinder-upload-dropbox {
  border-color: rgba(0, 0, 0, 0.5);
}
.elfinder-dialog .elfinder-upload-dropbox.ui-state-hover {
  background: rgba(0, 0, 0, 0.7);
}
.elfinder-dialog .elfinder-upload-dirselect {
  background: none;
}
.elfinder-dialog.elfinder-dialog-resize .ui-button {
  margin: 3px;
}
.elfinder .elfinder-navdock {
  border: 0;
}
.elfinder-notify-cancel .ui-state-hover {
  background: none;
  color: #eeeeee;
}
.elfinder-quicklook-navbar-icon {
  background: none;
  font-size: 24px;
}
.elfinder-quicklook-info-data {
  color: #222;
}
.elfinder-quicklook-preview-text-wrapper {
  background: #fff;
}
/**
 * Ace Editor
 */
#ace_settingsmenu {
  box-shadow: 0 1px 30px rgba(0, 0, 0, 0.6);
  background-color: #ffffff;
  color: #222;
}
.ace_optionsMenuEntry:hover {
  background-color: transparent;
}
.ace_optionsMenuEntry button[ace_selected_button=true] {
  box-shadow: none;
}
