<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'PhpParser\\' => array($vendorDir . '/nikic/php-parser/lib/PhpParser'),
    'FileManagerAdvanced\\PhpParser\\' => array($baseDir . '/src'),
);
